==> iplass-core-3.0.5.jar: schema/sql/ddl/oracle_partition/obj_ref.sql <==
/* drop/create OBJ_REF */
DROP TABLE "OBJ_REF" CASCADE CONSTRAINT;

CREATE TABLE "OBJ_REF" 
(
    "TENANT_ID" NUMBER(7,0) NOT NULL, 
    "OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "REF_DEF_ID" VARCHAR2(128) NOT NULL, 
    "OBJ_ID" VARCHAR2(64) NOT NULL, 
    "OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL,
    "TARGET_OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "TARGET_OBJ_ID" VARCHAR2(64) NOT NULL,
    "TARGET_OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL
)
PARTITION BY RANGE (TENANT_ID) INTERVAL(1)
SUBPARTITION BY HASH (OBJ_DEF_ID) SUBPARTITIONS 8
(
    PARTITION OBJ_REF_0 VALUES LESS THAN (1)
)
;

CREATE INDEX "OBJ_REF_INDEX1" ON "OBJ_REF" ("TENANT_ID", "OBJ_DEF_ID", "OBJ_ID") LOCAL;
CREATE INDEX "OBJ_REF_INDEX2" ON "OBJ_REF" ("TENANT_ID", "TARGET_OBJ_DEF_ID", "TARGET_OBJ_ID") LOCAL;

/* drop/create OBJ_REF */
DROP TABLE "OBJ_REF__MTP" CASCADE CONSTRAINT;

CREATE TABLE "OBJ_REF__MTP" 
(
    "TENANT_ID" NUMBER(7,0) NOT NULL, 
    "OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "REF_DEF_ID" VARCHAR2(128) NOT NULL, 
    "OBJ_ID" VARCHAR2(64) NOT NULL, 
    "OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL,
    "TARGET_OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "TARGET_OBJ_ID" VARCHAR2(64) NOT NULL,
    "TARGET_OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL
)
PARTITION BY RANGE (TENANT_ID) INTERVAL(1)
SUBPARTITION BY HASH (OBJ_DEF_ID) SUBPARTITIONS 8
(
    PARTITION OBJ_REF__MTP_0 VALUES LESS THAN (1)
)
;

CREATE INDEX "OBJ_REF__MTP_INDEX1" ON "OBJ_REF__MTP" ("TENANT_ID", "OBJ_DEF_ID", "OBJ_ID") LOCAL;
CREATE INDEX "OBJ_REF__MTP_INDEX2" ON "OBJ_REF__MTP" ("TENANT_ID", "TARGET_OBJ_DEF_ID", "TARGET_OBJ_ID") LOCAL;

/* drop/create OBJ_REF */
DROP TABLE "OBJ_REF__USER" CASCADE CONSTRAINT;

CREATE TABLE "OBJ_REF__USER" 
(
    "TENANT_ID" NUMBER(7,0) NOT NULL, 
    "OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "REF_DEF_ID" VARCHAR2(128) NOT NULL, 
    "OBJ_ID" VARCHAR2(64) NOT NULL, 
    "OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL,
    "TARGET_OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "TARGET_OBJ_ID" VARCHAR2(64) NOT NULL,
    "TARGET_OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL
)
PARTITION BY RANGE (TENANT_ID) INTERVAL(1)
SUBPARTITION BY HASH (OBJ_DEF_ID) SUBPARTITIONS 8
(
    PARTITION OBJ_REF__USER_0 VALUES LESS THAN (1)
)
;

CREATE INDEX "OBJ_REF__USER_INDEX1" ON "OBJ_REF__USER" ("TENANT_ID", "OBJ_DEF_ID", "OBJ_ID") LOCAL;
CREATE INDEX "OBJ_REF__USER_INDEX2" ON "OBJ_REF__USER" ("TENANT_ID", "TARGET_OBJ_DEF_ID", "TARGET_OBJ_ID") LOCAL;

==> iplass-core-4.0.3.jar: schema/sql/ddl/oracle_partition/obj_ref.sql <==
/* drop/create OBJ_REF */
DROP TABLE "OBJ_REF" CASCADE CONSTRAINT;

CREATE TABLE "OBJ_REF" 
(
    "TENANT_ID" NUMBER(7,0) NOT NULL, 
    "OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "REF_DEF_ID" VARCHAR2(128) NOT NULL, 
    "OBJ_ID" VARCHAR2(64) NOT NULL, 
    "OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL,
    "TARGET_OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "TARGET_OBJ_ID" VARCHAR2(64) NOT NULL,
    "TARGET_OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL
)
PARTITION BY RANGE (TENANT_ID) INTERVAL(1)
SUBPARTITION BY HASH (OBJ_DEF_ID) SUBPARTITIONS 8
(
    PARTITION OBJ_REF_0 VALUES LESS THAN (1)
)
;

CREATE INDEX "OBJ_REF_INDEX1" ON "OBJ_REF" ("TENANT_ID", "OBJ_DEF_ID", "OBJ_ID", "REF_DEF_ID") LOCAL;
CREATE INDEX "OBJ_REF_INDEX2" ON "OBJ_REF" ("TENANT_ID", "TARGET_OBJ_DEF_ID", "TARGET_OBJ_ID", "REF_DEF_ID") LOCAL;

/* drop/create OBJ_REF */
DROP TABLE "OBJ_REF__MTP" CASCADE CONSTRAINT;

CREATE TABLE "OBJ_REF__MTP" 
(
    "TENANT_ID" NUMBER(7,0) NOT NULL, 
    "OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "REF_DEF_ID" VARCHAR2(128) NOT NULL, 
    "OBJ_ID" VARCHAR2(64) NOT NULL, 
    "OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL,
    "TARGET_OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "TARGET_OBJ_ID" VARCHAR2(64) NOT NULL,
    "TARGET_OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL
)
PARTITION BY RANGE (TENANT_ID) INTERVAL(1)
SUBPARTITION BY HASH (OBJ_DEF_ID) SUBPARTITIONS 8
(
    PARTITION OBJ_REF__MTP_0 VALUES LESS THAN (1)
)
;

CREATE INDEX "OBJ_REF__MTP_INDEX1" ON "OBJ_REF__MTP" ("TENANT_ID", "OBJ_DEF_ID", "OBJ_ID", "REF_DEF_ID") LOCAL;
CREATE INDEX "OBJ_REF__MTP_INDEX2" ON "OBJ_REF__MTP" ("TENANT_ID", "TARGET_OBJ_DEF_ID", "TARGET_OBJ_ID", "REF_DEF_ID") LOCAL;

/* drop/create OBJ_REF */
DROP TABLE "OBJ_REF__USER" CASCADE CONSTRAINT;

CREATE TABLE "OBJ_REF__USER" 
(
    "TENANT_ID" NUMBER(7,0) NOT NULL, 
    "OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "REF_DEF_ID" VARCHAR2(128) NOT NULL, 
    "OBJ_ID" VARCHAR2(64) NOT NULL, 
    "OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL,
    "TARGET_OBJ_DEF_ID" VARCHAR2(128) NOT NULL, 
    "TARGET_OBJ_ID" VARCHAR2(64) NOT NULL,
    "TARGET_OBJ_VER" NUMBER(10,0) DEFAULT 0 NOT NULL
)
PARTITION BY RANGE (TENANT_ID) INTERVAL(1)
SUBPARTITION BY HASH (OBJ_DEF_ID) SUBPARTITIONS 8
(
    PARTITION OBJ_REF__USER_0 VALUES LESS THAN (1)
)
;

CREATE INDEX "OBJ_REF__USER_INDEX1" ON "OBJ_REF__USER" ("TENANT_ID", "OBJ_DEF_ID", "OBJ_ID", "REF_DEF_ID") LOCAL;
CREATE INDEX "OBJ_REF__USER_INDEX2" ON "OBJ_REF__USER" ("TENANT_ID", "TARGET_OBJ_DEF_ID", "TARGET_OBJ_ID", "REF_DEF_ID") LOCAL;
